==> moodle_1.3.1.orig.tar.gz: moodle/lang/es/quiz.php <==
<?PHP // $Id: quiz.php,v 1.18 2004/05/23 11:59:48 barias Exp $ 
      // quiz.php - created with Moodle 1.3 Nearly Ready (2004052000)


$string['acceptederror'] = 'Margen de error';
$string['addingquestions'] = 'Esta parte de la pgina es el lugar para administrar las preguntas. Las preguntas se agrupan en categoras para ayudarlo en la organizacin, pero pueden ser utilizadas por cualquier cuestionario en su curso o en otro curso si usted decide \'publicarlas\'.<br />Despus seleccionar o crear una categora podr crear o editar preguntas. Puede seleccionar cualquiera de esas preguntas para agregarlas al otro lado de la pgina.';
$string['addquestions'] = 'Agregar preguntas';
$string['addquestionstoquiz'] = 'Agregar preguntas al presente cuestionario';
$string['addselectedtoquiz'] = 'Agregar al cuestionario';
$string['aiken'] = 'Formato Aiken';
$string['allowreview'] = 'Permitir revisin';
$string['alreadysubmitted'] = 'Parece que usted ya respondi este cuestionario';
$string['alwaysavailable'] = 'Siempre disponible';
$string['answer'] = 'Respuesta';
$string['answerhowmany'] = 'Una o varias respuestas?';
$string['answersingleno'] = 'Se permiten varias respuestas';
$string['answersingleyes'] = 'Slo una respuesta';
$string['answerswithacceptederrormarginmustbenumeric'] = 'Las respuestas con margen de error deben ser numricas';
$string['answertoolong'] = 'Respuesta demasiado larga despus de la lnea $a (mx. 255 caracteres)';
$string['aon'] = 'Formato AON';
$string['attempt'] = 'Intento $a';
$string['attemptfirst'] = 'Primer intento';
$string['attemptincomplete'] = 'Este intento (de $a) no se ha completado an.';
$string['attemptlast'] = 'ltimo intento';
$string['attemptquiznow'] = 'Comenzar';
$string['attempts'] = 'Intentos';
$string['attemptsallowed'] = 'Intentos permitidos';
$string['attemptsexist'] = 'Ya ha intentado contestar este cuestionario';
$string['attemptsunlimited'] = 'Intentos ilimitados';
$string['backtoquiz'] = 'Regresar a edicin de cuestionario';
$string['bestgrade'] = 'Calificacin mxima';
$string['blackboard'] = 'Blackboard';
$string['calculatedquestion'] = 'Pregunta calculada no permitida en la lnea $a. La pregunta no se tendr en cuenta';
$string['caseno'] = 'Igual maysculas que minsculas';
$string['casesensitive'] = 'Diferencia entre maysculas y minsculas';
$string['caseyes'] = 'Maysculas y minsculas deben coincidir';
$string['categories'] = 'Categoras';
$string['category'] = 'Categora';
$string['categoryinfo'] = 'Informacin de la categora';
$string['categorymove'] = 'La categora \'$a->name\' contiene $a->count preguntas. Por favor elija otra categora.';
$string['categorymoveto'] = 'Mover a esta categora';
$string['choice'] = 'Eleccin';
$string['choices'] = 'Opciones disponibles';
$string['correctanswer'] = 'Respuesta correcta';
$string['correctanswers'] = 'Respuestas correctas';
$string['corrresp'] = 'Respuesta Correcta';
$string['countdown'] = 'Cuenta atrs';
$string['countdownfinished'] = 'Este cuestionario se est cerrando, debe enviar sus respuestas ahora.';
$string['countdowntenminutes'] = 'El cuestionario se cerrar en diez minutos.';
$string['coursetestmanager'] = 'Formato de Administracin de Test de Curso';
$string['createmultiple'] = 'Crear mltiples preguntas';
$string['createnewquestion'] = 'Crear una pregunta nueva';
$string['custom'] = 'Formato personalizado';
$string['daysavailable'] = 'Das disponible';
$string['default'] = 'Por defecto';
$string['defaultgrade'] = 'Calificacin por defecto de la pregunta';
$string['defaultinfo'] = 'Categora por defecto para las preguntas.';
$string['deleteattemptcheck'] = 'Est seguro de que desea borrar definitivamente estos intentos?';
$string['deletequestioncheck'] = 'Est seguro de que desea borrar \'$a\'?';
$string['description'] = 'Descripcin';
$string['discrimination'] = 'ndice Discrim.';
$string['eachattemptbuildsonthelast'] = 'Cada intento se basa en el anterior';
$string['editcategories'] = 'Editar categoras';
$string['editingdescription'] = 'Editando la descripcin';
$string['editingmatch'] = 'Editando pregunta de acierto';
$string['editingmultianswer'] = 'Editando respuestas incrustadas (Cloze)';
$string['editingmultichoice'] = 'Editando una pregunta de opcin mltiple';
$string['editingnumerical'] = 'Editando una pregunta numrica';
$string['editingquestion'] = 'Editando pregunta';
$string['editingquiz'] = 'Editando cuestionario';
$string['editingrandom'] = 'Editando pregunta aleatoria';
$string['editingrandomsamatch'] = 'Editando pregunta de emparejamiento de respuesta corta aleatoria';
$string['editingshortanswer'] = 'Editando una pregunta de respuesta corta';
$string['editingtruefalse'] = 'Editando una pregunta verdadero/falso';
$string['editquestions'] = 'Editar preguntas';
$string['errorsdetected'] = '$a error(es) detectado(s)';
$string['false'] = 'Falso';
$string['feedback'] = 'Respuesta';
$string['fileformat'] = 'Formato de archivo';
$string['filloutoneanswer'] = 'Debe llenar al menos una respuesta posible. Las respuestas en blanco no sern utilizadas.';
$string['filloutthreequestions'] = 'Debe llenar al menos tres preguntas. Las que deje en blanco no sern utilizadas.';
$string['fillouttwochoices'] = 'Debe elegir al menos dos opciones. Las opciones en blanco no sern utilizadas.';
$string['fractionsaddwrong'] = 'Las calificaciones positivas otorgadas no suman 100%% sino $a%%<BR>Desea regresar y corregir esta pregunta?';
$string['fractionsnomax'] = 'Una de las preguntas debe ser 100%% para que sea<BR>posible alcanzar la calificacin mxima<BR>Desea regresar y corregir esta pregunta?';
$string['gift'] = 'Formato GIFT';
$string['gradeaverage'] = 'Promedio de calificaciones';
$string['gradehighest'] = 'Calificacin ms alta';
$string['grademethod'] = 'Mtodo de calificacin';
$string['guestsno'] = 'Lo sentimos, los invitados no pueden ver o responder cuestionarios';
$string['imagedisplay'] = 'Imagen a mostrar';
$string['imagemissing'] = 'Imagen no disponible en la lnea $a. El archivo no se tendr en cuenta';
$string['importquestions'] = 'Importar preguntas de un archivo';
$string['indivresp'] = 'Respuestas de los individuos a cada tem';
$string['introduction'] = 'Introduccin';
$string['itemanal'] = 'Anlisis de respuestas por tem';
$string['listitems'] = 'Lista de tems del cuestionario';
$string['marks'] = 'Puntos';
$string['match'] = 'Emparejamiento';
$string['matchanswer'] = 'Respuesta emparejada';
$string['missinganswer'] = 'Muy pocos elementos :ANSWER :Lx, :Rx para la pregunta de la lnea $a. Debe definir al menos dos respuestas posibles';
$string['missingcorrectanswer'] = 'Debe especificar la respuesta correcta';
$string['missingname'] = 'La pregunta no tiene nombre';
$string['missingquestion'] = 'Falta una etiqueta de pregunta despus de la lnea $a';
$string['missingquestiontext'] = 'La pregunta no tiene texto';
$string['missingword'] = 'Formato de palabra perdida';
$string['modulename'] = 'Cuestionario';
$string['modulenameplural'] = 'Cuestionarios';
$string['multianswer'] = 'Respuestas incrustadas (Cloze)';
$string['multichoice'] = 'Opcin mltiple';
$string['name'] = 'Nombre';
$string['noanswers'] = 'No se seleccion ninguna respuesta';
$string['noattempts'] = 'No se ha intentado responder este cuestionario';
$string['nomoreattempts'] = 'No se permiten ms intentos';
$string['noquestions'] = 'An no se han agregado preguntas';
$string['noresponse'] = 'Sin respuesta';
$string['noreview'] = 'No est autorizado para revisar este cuestionario';
$string['noreviewuntil'] = 'No est autorizado para revistar este cuestionario hasta el $a';
$string['notenoughanswers'] = 'Este tipo de pregunta requiere al menos $a respuestas';
$string['notenoughsubquestions'] = 'No se han definido suficientes subpreguntas.<br> Quiere regresar y arreglar esta pregunta?';
$string['numerical'] = 'Numrico';
$string['paragraphquestion'] = 'Pregunta de pargrafo no permitida en la lnea $a. La pregunta no se tendr en cuenta';
$string['percentcorrect'] = 'Porcentaje correcto';
$string['publish'] = 'Publicar';
$string['qti'] = 'Formato IMS QTI';
$string['question'] = 'Pregunta';
$string['questioninuse'] = 'La pregunta \'$a\' est en uso:';
$string['questionname'] = 'Nombre de la pregunta';
$string['questionnametoolong'] = 'El nombre de la pregunta de la lnea $a es demasiado largo (mx. 255 car.). Ha sido truncado.';
$string['questions'] = 'Preguntas';
$string['quizavailable'] = 'El cuestionario est disponible hasta el $a';
$string['quizclose'] = 'Cerrar cuestionario';
$string['quizclosed'] = 'Este cuestionario est cerrado el $a';
$string['quizcloses'] = 'Cuestionario cerrado';
$string['quiznotavailable'] = 'Este cuestionario no estar disponible hasta el $a';
$string['quizopen'] = 'Abrir cuestionario';
$string['quizopens'] = 'Cuestionario abierto';
$string['random'] = 'Pregunta aleatoria';
$string['randomcreate'] = 'Crear preguntas aleatorias';
$string['randomsamatch'] = 'Emparejamiento aleatorio de respuestas cortas';
$string['randomsamatchcreate'] = 'Crear preguntas de emparejamiento aleatorio de respuestas cortas';
$string['randomsamatchintro'] = 'Para cada una de las siguientes preguntas seleccione la respuesta que haga juego del men.';
$string['randomsamatchnumber'] = 'Nmero de preguntas seleccionadas';
$string['readytosend'] = 'Est a punto de enviar su cuestionario para que sea evaluado. Est seguro de que desea continuar?';
$string['recentlyaddedquestion'] = 'Pregunta agregada recientemente';
$string['regrade'] = 'Recalificar todos los intentos';
$string['regradecomplete'] = 'Todos los intentos han sido recalificados';
$string['regradecount'] = 'Se han cambiado $a->changed de $a->attempt calificaciones';
$string['rename'] = 'Renombrar';
$string['report'] = 'Informes';
$string['reportfullstat'] = 'Estadsticas detalladas';
$string['reportmulti_percent'] = 'Porcentajes mtiples';
$string['reportmulti_q_x_student'] = 'Opciones multi-estudiante';
$string['reportmulti_resp'] = 'Respuestas individuales';
$string['reportoverview'] = 'Vista general';
$string['reportregrade'] = 'Recalificar intentos';
$string['reportsimplestat'] = 'Estadstica simple';
$string['review'] = 'Revisin';
$string['save'] = 'Guardar';
$string['savegrades'] = 'Guardar calificaciones';
$string['savemyanswers'] = 'Guardar mis respuestas';
$string['savequiz'] = 'Guardar todo el cuestionario';
$string['score'] = 'Puntuacin bruta';
$string['select'] = 'Seleccionar';
$string['selectall'] = 'Seleccionar todo';
$string['selectcategoryabove'] = 'Seleccione una categora';
$string['shortanswer'] = 'Respuesta corta';
$string['show'] = 'Mostrar';
$string['showcorrectanswer'] = 'Mostrar la respuesta correcta al finalizar?';
$string['showfeedback'] = 'Mostrar resultado al finalizar?';
$string['shuffleanswers'] = 'Barajar respuestas';
$string['shufflequestions'] = 'Barajar preguntas';
$string['time'] = 'Tiempo';
$string['timecompleted'] = 'Completado';
$string['timetaken'] = 'Tiempo empleado';
$string['toomanyrandom'] = 'El nmero requerido de preguntas es mayor de las que contiene esta categora.';
$string['true'] = 'Verdadero';
$string['truefalse'] = 'Verdadero/Falso';
$string['type'] = 'Tipo';
$string['unknowntype'] = 'Tipo de pregunta no permitida en la lnea $a. La pregunta no se tendr en cuenta';
$string['viewallanswers'] = 'Ver $a cuestionarios resueltos';
$string['viewallreports'] = 'Ver los informes de $a intentos';
$string['warningsdetected'] = '$a advertencia(s) detectada(s)';
$string['webct'] = 'Formato WebCT';
$string['withsummary'] = 'con estadsticas resumidas';
$string['wronggrade'] = 'Calificacin equivocada (despus de la lnea $a) :';
$string['yourfinalgradeis'] = 'Su calificacin final en este cuestionario es $a';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/es/quiz.php <==
<?PHP // $Id$ 
      // quiz.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004093001)


$string['acceptederror'] = 'Margen de error';
$string['addingquestions'] = 'Esta parte de la pgina es el lugar para administrar las preguntas. Las preguntas se agrupan en categoras para ayudarlo en la organizacin, pero pueden ser utilizadas por cualquier cuestionario en su curso o en otro curso si usted decide \'publicarlas\'.<br />Despus seleccionar o crear una categora podr crear o editar preguntas. Puede seleccionar cualquiera de esas preguntas para agregarlas al otro lado de la pgina.';
$string['addquestions'] = 'Agregar preguntas';
$string['addquestionstoquiz'] = 'Agregar preguntas al presente cuestionario';
$string['addselectedtoquiz'] = 'Agregar al cuestionario';
$string['aiken'] = 'Formato Aiken';
$string['allowreview'] = 'Permitir revisin';
$string['alreadysubmitted'] = 'Parece que usted ya respondi este cuestionario';
$string['alternativeunits'] = 'Unidades alternativas';
$string['alwaysavailable'] = 'Siempre disponible';
$string['answer'] = 'Respuesta';
$string['answerhowmany'] = 'Una o varias respuestas?';
$string['answersingleno'] = 'Se permiten varias respuestas';
$string['answersingleyes'] = 'Slo una respuesta';
$string['answerswithacceptederrormarginmustbenumeric'] = 'Las respuestas con margen de error deben ser numricas';
$string['answertoolong'] = 'Respuesta demasiado larga despus de la lnea $a (mx. 255 caracteres)';
$string['aon'] = 'Formato AON';
$string['attempt'] = 'Intento $a';
$string['attemptfirst'] = 'Primer intento';
$string['attemptincomplete'] = 'Este intento (de $a) no se ha completado an.';
$string['attemptlast'] = 'ltimo intento';
$string['attemptquiznow'] = 'Comenzar';
$string['attempts'] = 'Intentos';
$string['attemptsallowed'] = 'Intentos permitidos';
$string['attemptsexist'] = 'Ya ha intentado contestar este cuestionario';
$string['attemptsunlimited'] = 'Intentos ilimitados';
$string['back'] = 'Regresar a visin previa de la pregunta';
$string['backtoquiz'] = 'Regresar a edicin de cuestionario';
$string['bestgrade'] = 'Calificacin mxima';
$string['blackboard'] = 'Blackboard';
$string['calculated'] = 'Calculadas';
$string['calculatedquestion'] = 'Pregunta calculada no permitida en la lnea $a. La pregunta no se tendr en cuenta';
$string['caseno'] = 'Igual maysculas que minsculas';
$string['casesensitive'] = 'Diferencia entre maysculas y minsculas';
$string['caseyes'] = 'Maysculas y minsculas deben coincidir';
$string['categories'] = 'Categoras';
$string['category'] = 'Categora';
$string['categoryinfo'] = 'Informacin de la categora';
$string['categorymove'] = 'La categora \'$a->name\' contiene $a->count preguntas. Por favor elija otra categora.';
$string['categorymoveto'] = 'Mover a esta categora';
$string['checkanswer'] = 'Comprobar';
$string['choice'] = 'Eleccin';
$string['choices'] = 'Opciones disponibles';
$string['choosedatasetproperties'] = 'Elegir propiedades del conjunto de datos';
$string['close'] = 'Cerrar vista previa';
$string['confirmstartattempt'] = 'Este cuestionario ha de contestarse en un tiempo limitado. Est seguro de que desea comenzar?';
$string['correctanswer'] = 'Respuesta correcta';
$string['correctanswerformula'] = 'Frmula de respuesta correcta';
$string['correctanswerlength'] = 'Cifras significativas';
$string['correctanswers'] = 'Respuestas correctas';
$string['correctanswershows'] = 'La respuesta correcta muestra';
$string['corrresp'] = 'Respuesta Correcta';
$string['countdown'] = 'Cuenta atrs';
$string['countdownfinished'] = 'Este cuestionario se est cerrando, debe enviar sus respuestas ahora.';
$string['countdowntenminutes'] = 'El cuestionario se cerrar en diez minutos.';
$string['coursetestmanager'] = 'Formato de Administracin de Test de Curso';
$string['createmultiple'] = 'Crear mltiples preguntas';
$string['createnewquestion'] = 'Crear una pregunta nueva';
$string['custom'] = 'Formato personalizado';
$string['datasetdefinitions'] = 'Definiciones reutilizables del conjunto de datos para la categora $a';
$string['datasetnumber'] = 'Nmero';
$string['daysavailable'] = 'Das disponible';
$string['decimalformat'] = 'decimales';
$string['decimals'] = ' con $a';
$string['default'] = 'Por defecto';
$string['defaultgrade'] = 'Calificacin por defecto de la pregunta';
$string['defaultinfo'] = 'Categora por defecto para las preguntas.';
$string['deleteattemptcheck'] = 'Est seguro de que desea borrar definitivamente estos intentos?';
$string['deletequestioncheck'] = 'Est seguro de que desea borrar \'$a\'?';
$string['description'] = 'Descripcin';
$string['discrimination'] = 'ndice Discrim.';
$string['eachattemptbuildsonthelast'] = 'Cada intento se basa en el anterior';
$string['editcategories'] = 'Editar categoras';
$string['editdatasets'] = 'Editar datos';
$string['editingcalculated'] = 'Editando pregunta calculada';
$string['editingdescription'] = 'Editando la descripcin';
$string['editingmatch'] = 'Editando pregunta de acierto';
$string['editingmultianswer'] = 'Editando respuestas incrustadas (Cloze)';
$string['editingmultichoice'] = 'Editando una pregunta de opcin mltiple';
$string['editingnumerical'] = 'Editando una pregunta numrica';
$string['editingquestion'] = 'Editando pregunta';
$string['editingquiz'] = 'Editando cuestionario';
$string['editingrandom'] = 'Editando pregunta aleatoria';
$string['editingrandomsamatch'] = 'Editando pregunta de emparejamiento de respuesta corta aleatoria';
$string['editingshortanswer'] = 'Editando una pregunta de respuesta corta';
$string['editingtruefalse'] = 'Editando una pregunta verdadero/falso';
$string['editquestions'] = 'Editar preguntas';
$string['errorsdetected'] = '$a error(es) detectado(s)';
$string['existingcategory1'] = 'un literal de un conjunto existente de literales que tambin son usados por otras preguntas en esta categora';
$string['existingcategory2'] = 'un archivo de un conjunto existente de archivos que tambin son usados por otras preguntas en esta categora';
$string['existingcategory3'] = 'un enlace de un conjunto existente de enlaces que tambin son usados por otras preguntas en esta categora';
$string['exportfilename'] = 'cuestionario';
$string['exportname'] = 'Nombre del archivo';
$string['exportnameformat'] = '%%Y%%m%%d-%%H%%M';
$string['exportquestions'] = 'Exportar preguntas a un archivo';
$string['false'] = 'Falso';
$string['feedback'] = 'Respuesta';
$string['file'] = 'Archivo';
$string['fileformat'] = 'Formato de archivo';
$string['filloutoneanswer'] = 'Debe llenar al menos una respuesta posible. Las respuestas en blanco no sern utilizadas.';
$string['filloutthreequestions'] = 'Debe llenar al menos tres preguntas. Las que deje en blanco no sern utilizadas.';
$string['fillouttwochoices'] = 'Debe elegir al menos dos opciones. Las opciones en blanco no sern utilizadas.';
$string['forceregeneration'] = 'forzar regeneracin';
$string['fractionsaddwrong'] = 'Las calificaciones positivas otorgadas no suman 100%% sino $a%%<br />Desea regresar y corregir esta pregunta?';
$string['fractionsnomax'] = 'Una de las preguntas debe ser 100%% para que sea<br />posible alcanzar la calificacin mxima<br />Desea regresar y corregir esta pregunta?';
$string['functiontakesatleasttwo'] = 'La funcin $a debe tener al menos dos argumentos';
$string['functiontakesnoargs'] = 'La funcin $a no contiene argumentos';
$string['functiontakesonearg'] = 'La funcin $a debe tener exactamente un argumento';
$string['functiontakesoneortwoargs'] = 'La funcin $a debe tener uno o dos argumentos';
$string['functiontakestwoargs'] = 'La funcin $a debe tener exactamente dos argumentos';
$string['generatevalue'] = 'Generar un nuevo valor entre';
$string['geometric'] = 'Geomtrica';
$string['gift'] = 'Formato GIFT';
$string['gradeaverage'] = 'Promedio de calificaciones';
$string['gradehighest'] = 'Calificacin ms alta';
$string['grademethod'] = 'Mtodo de calificacin';
$string['guestsno'] = 'Lo sentimos, los invitados no pueden ver o responder cuestionarios';
$string['illegalformulasyntax'] = 'Sintaxis de frmula ilegal que comienza con \'$a\'';
$string['imagedisplay'] = 'Imagen a mostrar';
$string['imagemissing'] = 'Imagen no disponible en la lnea $a. El archivo no se tendr en cuenta';
$string['importquestions'] = 'Importar preguntas de un archivo';
$string['indivresp'] = 'Respuestas de los individuos a cada tem';
$string['introduction'] = 'Introduccin';
$string['itemanal'] = 'Anlisis de respuestas por tem';
$string['itemdefinition'] = 'Definicin';
$string['keptcategory1'] = 'un literal del mismo conjunto reutilizable de categoras de literales anterior';
$string['keptcategory2'] = 'un archivo del mismo conjunto reutilizable de categoras de archivos anterior';
$string['keptcategory3'] = 'un enlace del mismo conjunto reutilizable de categoras de enlaces anterior';
$string['keptlocal1'] = 'un literal del mismo conjunto privado de categoras de literales anterior';
$string['keptlocal2'] = 'un archivo del mismo conjunto privado de categoras de archivos anterior';
$string['keptlocal3'] = 'un enlace del mismo conjunto privado de categoras de enlaces anterior';
$string['link'] = 'Enlace';
$string['listitems'] = 'Lista de tems del cuestionario';
$string['literal'] = 'Literal';
$string['loguniform'] = 'dgitos, de una distribucin log-uniforme';
$string['marks'] = 'Puntos';
$string['match'] = 'Emparejamiento';
$string['matchanswer'] = 'Respuesta emparejada';
$string['max'] = 'Mx';
$string['min'] = 'Mn';
$string['minutes'] = 'Minutos';
$string['missinganswer'] = 'Muy pocos elementos :ANSWER :Lx, :Rx para la pregunta de la lnea $a. Debe definir al menos dos respuestas posibles';
$string['missingcorrectanswer'] = 'Debe especificar la respuesta correcta';
$string['missingname'] = 'La pregunta no tiene nombre';
$string['missingquestion'] = 'Falta una etiqueta de pregunta despus de la lnea $a';
$string['missingquestiontext'] = 'La pregunta no tiene texto';
$string['missingword'] = 'Formato de palabra perdida';
$string['modulename'] = 'Cuestionario';
$string['modulenameplural'] = 'Cuestionarios';
$string['multianswer'] = 'Respuestas incrustadas (Cloze)';
$string['multichoice'] = 'Opcin mltiple';
$string['multiplier'] = 'Multiplicador';
$string['name'] = 'Nombre';
$string['newcategory1'] = 'un literal de un nuevo conjunto de literales que puede ser usado tambin por otras preguntas en esta categora';
$string['newcategory2'] = 'un archivo de un nuevo conjunto de archivos que puede ser usado tambin por otras preguntas en esta categora';
$string['newcategory3'] = 'un enlace de un nuevo conjunto de enlaces que puede ser usado tambin por otras preguntas en esta categora';
$string['newlocal1'] = 'un literal de un nuevo conjunto de literales que puede ser usado solamente por esta pregunta';
$string['newlocal2'] = 'un archivo de un nuevo conjunto de archivos que puede ser usado solamente por esta pregunta';
$string['newlocal3'] = 'un enlace de un nuevo conjunto de enlaces que puede ser usado solamente por esta pregunta';
$string['noanswers'] = 'No se seleccion ninguna respuesta';
$string['noattempts'] = 'No se ha intentado responder este cuestionario';
$string['nodataset'] = 'nada - no es una wild card';
$string['nominal'] = 'Nominal';
$string['nomoreattempts'] = 'No se permiten ms intentos';
$string['nopossibledatasets'] = 'No datos posibles';
$string['noquestions'] = 'An no se han agregado preguntas';
$string['noresponse'] = 'Sin respuesta';
$string['noreview'] = 'No est autorizado para revisar este cuestionario';
$string['noreviewuntil'] = 'No est autorizado para revistar este cuestionario hasta el $a';
$string['noscript'] = 'Para continuar, JavaScript debe estar habilitado';
$string['notenoughanswers'] = 'Este tipo de pregunta requiere al menos $a respuestas';
$string['notenoughsubquestions'] = 'No se han definido suficientes subpreguntas.<br /> Quiere regresar y arreglar esta pregunta?';
$string['numerical'] = 'Numrico';
$string['optional'] = 'opcional';
$string['overdue'] = 'Vencido';
$string['paragraphquestion'] = 'Pregunta de pargrafo no permitida en la lnea $a. La pregunta no se tendr en cuenta';
$string['parentlanguage'] = 'es';
$string['passworderror'] = 'La contrasea es incorrecta';
$string['percentcorrect'] = 'Porcentaje correcto';
$string['popup'] = 'Mostrar el cuestionario en una ventana \"segura\"';
$string['preview'] = 'Vista previa';
$string['previewquestion'] = 'Ver pregunta';
$string['publish'] = 'Publicar';
$string['publishedit'] = 'Necesita tener permiso en el curso para aadir o editar preguntas en esta categora';
$string['qti'] = 'Formato IMS QTI';
$string['question'] = 'Pregunta';
$string['questioninuse'] = 'La pregunta \'$a\' est en uso:';
$string['questionname'] = 'Nombre de la pregunta';
$string['questionnametoolong'] = 'El nombre de la pregunta de la lnea $a es demasiado largo (mx. 255 car.). Ha sido truncado.';
$string['questions'] = 'Preguntas';
$string['quizavailable'] = 'El cuestionario est disponible hasta el $a';
$string['quizclose'] = 'Cerrar cuestionario';
$string['quizclosed'] = 'Este cuestionario est cerrado el $a';
$string['quizcloses'] = 'Cuestionario cerrado';
$string['quiznotavailable'] = 'Este cuestionario no estar disponible hasta el $a';
$string['quizopen'] = 'Abrir cuestionario';
$string['quizopens'] = 'Cuestionario abierto';
$string['quiztimelimit'] = 'Lmite de tiempo: $a';
$string['quiztimer'] = 'Contador';
$string['random'] = 'Pregunta aleatoria';
$string['randomcreate'] = 'Crear preguntas aleatorias';
$string['randomsamatch'] = 'Emparejamiento aleatorio de respuestas cortas';
$string['randomsamatchcreate'] = 'Crear preguntas de emparejamiento aleatorio de respuestas cortas';
$string['randomsamatchintro'] = 'Para cada una de las siguientes preguntas seleccione la respuesta que haga juego del men.';
$string['randomsamatchnumber'] = 'Nmero de preguntas seleccionadas';
$string['readytosend'] = 'Est a punto de enviar su cuestionario para que sea evaluado. Est seguro de que desea continuar?';
$string['recentlyaddedquestion'] = 'Pregunta agregada recientemente';
$string['regrade'] = 'Recalificar todos los intentos';
$string['regradecomplete'] = 'Todos los intentos han sido recalificados';
$string['regradecount'] = 'Se han cambiado $a->changed de $a->attempt calificaciones';
$string['relative'] = 'Relativas';
$string['remove'] = 'Quitar';
$string['rename'] = 'Renombrar';
$string['report'] = 'Informes';
$string['reportfullstat'] = 'Estadsticas detalladas';
$string['reportmulti_percent'] = 'Porcentajes mtiples';
$string['reportmulti_q_x_student'] = 'Opciones multi-estudiante';
$string['reportmulti_resp'] = 'Respuestas individuales';
$string['reportoverview'] = 'Vista general';
$string['reportregrade'] = 'Recalificar intentos';
$string['reportsimplestat'] = 'Estadstica simple';
$string['requirepassword'] = 'Se requiere contrasea';
$string['requirepasswordmessage'] = 'Para contestar este cuestionario necesita conocer la contrasea';
$string['requiresubnet'] = 'Se requiere direccin de red';
$string['reuseifpossible'] = 'volver a usar las eliminadas previamente';
$string['review'] = 'Revisin';
$string['save'] = 'Guardar';
$string['savegrades'] = 'Guardar calificaciones';
$string['savemyanswers'] = 'Guardar mis respuestas';
$string['savequiz'] = 'Guardar todo el cuestionario';
$string['score'] = 'Puntuacin bruta';
$string['select'] = 'Seleccionar';
$string['selectall'] = 'Seleccionar todo';
$string['selectcategoryabove'] = 'Seleccione una categora';
$string['shortanswer'] = 'Respuesta corta';
$string['show'] = 'Mostrar';
$string['showcorrectanswer'] = 'Mostrar la respuesta correcta al finalizar?';
$string['showfeedback'] = 'Mostrar resultado al finalizar?';
$string['shuffleanswers'] = 'Barajar respuestas';
$string['shufflequestions'] = 'Barajar preguntas';
$string['significantfigures'] = 'con $a';
$string['significantfiguresformat'] = 'dgitos significativos';
$string['subneterror'] = 'Lo sentimos, este cuestionario ha sido bloqueado de modo que slo es accesible desde ciertas direcciones. En este momento su ordenador no est autorizado para usar este cuestionario.';
$string['substitutedby'] = 'sern sustitudas por';
$string['thischarset'] = 'iso-8859-1';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'es';
$string['time'] = 'Tiempo';
$string['timecompleted'] = 'Completado';
$string['timeleft'] = 'Tiempo restante';
$string['timelimit'] = 'Lmite de tiempo';
$string['timelimitexeeded'] = 'Lo sentimos. Se ha sobrepasado el lmite de tiempo.';
$string['timesup'] = 'Se ha pasado el tiempo!';
$string['timetaken'] = 'Tiempo empleado';
$string['tolerance'] = 'Tolerancia';
$string['tolerancetype'] = 'Tipo de tolerancia';
$string['toomanyrandom'] = 'El nmero requerido de preguntas es mayor de las que contiene esta categora.';
$string['true'] = 'Verdadero';
$string['truefalse'] = 'Verdadero/Falso';
$string['type'] = 'Tipo';
$string['uniform'] = 'defimales, de una distribucin uniforme';
$string['unit'] = 'Unidad';
$string['unknowntype'] = 'Tipo de pregunta no permitida en la lnea $a. La pregunta no se tendr en cuenta';
$string['unsupportedformulafunction'] = 'La funcin $a no est includa';
$string['viewallanswers'] = 'Ver $a cuestionarios resueltos';
$string['viewallreports'] = 'Ver los informes de $a intentos';
$string['warningsdetected'] = '$a advertencia(s) detectada(s)';
$string['webct'] = 'Formato WebCT';
$string['wildcard'] = 'Wild card';
$string['withsummary'] = 'con estadsticas resumidas';
$string['wronggrade'] = 'Calificacin equivocada (despus de la lnea $a) :';
$string['xml'] = 'Formato Moodle XML';
$string['yourfinalgradeis'] = 'Su calificacin final en este cuestionario es $a';
$string['zerosignificantfiguresnotallowed'] = 'La respuesta correcta no puede tener cero dgitos significativos!';

?>
